from chatushka.bot.matchers.admin import admin_matcher
from chatushka.bot.matchers.bobuk_jokes import jokes_matcher
from chatushka.bot.matchers.eight_ball import eight_ball_matcher
from chatushka.bot.matchers.helpers import helpers_matcher
from chatushka.bot.matchers.lukashenko import lukashenko_matcher
from chatushka.bot.matchers.suicide import suicide_matcher

__all__ = (
    "admin_matcher",
    "jokes_matcher",
    "eight_ball_matcher",
    "helpers_matcher",
    "suicide_matcher",
    "lukashenko_matcher",
)
